<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="capabilityTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></table-form>
    </basic-container>
  </div>
</template>

<script>
  import {fetchCapabilityList, delObj} from '@/api/aps/capability'
  import TableForm from './capability-form'
  import ttable from '@/views/common/ztt-table.vue';
  import {mapGetters} from 'vuex'
  export default {
    data () {
      return {
        ajaxFun:fetchCapabilityList,
        addOrUpdateVisible: false,
        resourceVisible: false,
        multipleSelection: [],
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:true,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'id',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //能力编号
            {minWidth:'140',prop:"capabilityNo",label:"能力编号",sort: true,isTrue:true,formatter: (row, column, cellValue) => {return cellValue;},isSearch:true,searchInfoType:'text', render:{fun:this.addOrUpdateHandle}},
            //能力名称
            {minWidth:'120',prop: "capabilityName",label:"能力名称",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //备注
            {minWidth:'200',prop: "remark",label:"备注",sort: true,isTrue:true,isSearch:false,searchInfoType:'text'},

          ],
          toolbar: [
            {
              text: '新增',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator:[
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:100,
            minWidth:100
          }
        },
        capabilityEnableList:[
          {
            value:true,
            label:'是'
          },
          {
            value:false,
            label:'否'
          }
        ],
      }
    },
    components: {
      TableForm,
      ttable
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getData () {
        this.$refs.capabilityTable.getDataList();
      },
      // 新增 / 修改
      addOrUpdateHandle (row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row==null?null:row.id)
        })
      },
      // 删除能力
      deleteHandle (row) {
        this.$confirm('是否确认删除能力名为:"'+row.capabilityName+'"', '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal:false,
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      },
      handleSelectionChange(val){
        this.multipleSelection = val
      }
    }

  }
</script>
